Rules
=====

.. automodule:: financepype.rules.trading_rule
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: financepype.rules.trading_rules_tracker
   :members:
   :undoc-members:
   :show-inheritance:
